@@ -3,24 +3,18 @@ from dataclasses import dataclass
 
 
 class Operation(Enum):
-    ALL = 0
-    IN = 1
-    OUT = 2
-    QIWI_CARD = 3
+    ALL = "ALL"
+    IN = "IN"
+    OUT = "OUT"
+    QIWI_CARD = "QIWI_CARD"
 
 
 class Source(Enum):
-    RUB = 0
-    USD = 1
-    EUR = 2
-
-
-class SourceCard(Enum):
-    CARD = 0
-
-
-class SourceMK(Enum):
-    MK = 0
+    RUB = "QW_RUB"
+    USD = "QW_USD"
+    EUR = "QW_EUR"
+    CARD = "CARD"
+    MK = "MK"
 
 
 class Status:
